import { APIClient, BrowserStackOptions, APIFetchOptions } from './api-client';
import type { operations } from './generated/openapi';
import type { FetchOptions } from "openapi-fetch";
/**
 * ScreenshotsClient represents a client for interacting with the BrowserStack Screenshots API.
 * @see https://www.browserstack.com/screenshots/api
 * @public
 */
export declare class ScreenshotsClient extends APIClient {
    /**
     * Constructs a new instance of the ScreenshotsClient class.
     * @param options - Optional configuration options for the client.
     */
    constructor(options?: BrowserStackOptions);
    /**
     * Retrieves the list of available browsers for taking screenshots.
     * @param options - Optional fetch options for the request.
     * @returns A promise that resolves to the response from the API.
     */
    getBrowsers(options?: FetchOptions<operations["getScreenshotsBrowsers"]>): Promise<({
        browser: string;
        browser_version: string;
    } & {
        os: string;
        os_version: string;
        device: string;
        real_mobile: boolean;
    })[]>;
    /**
     * Creates a new screenshots job.
     * @param body - The request body for creating the job.
     * @param options - Optional fetch options for the request.
     * @returns A promise that resolves to the response from the API.
     */
    createJob(body: operations["createScreenshotsJob"]["requestBody"]["content"]["application/json"], options?: APIFetchOptions<operations["createScreenshotsJob"]>): Promise<NonNullable<{
        job_id?: string | undefined;
        callback_url?: string | undefined;
        win_res?: string | undefined;
        mac_res?: string | undefined;
        quality?: "Compressed" | "Original" | undefined;
        wait_time?: number | undefined;
        orientation?: "portrait" | "landscape" | undefined;
        screenshots?: ({
            id: string;
            state: "failed" | "done" | "pending";
            url: string;
            os: string;
            os_version: string;
        } & ({
            device: string;
            browser?: string | undefined;
            browser_version?: string | undefined;
        } | {
            browser: string;
            browser_version: string;
        }) & {
            image_url?: string | undefined;
            thumb_url?: string | undefined;
            created_at?: string | undefined;
        })[] | undefined;
    } & {
        job_id: string;
    }>>;
    /**
     * Retrieves the details of a screenshots job.
     * @param jobId - The ID of the job to retrieve.
     * @param options - Optional fetch options for the request.
     * @returns A promise that resolves to the response from the API.
     */
    getJob(jobId: string, options?: APIFetchOptions<operations["getScreenshotsJob"]>): Promise<NonNullable<{
        job_id?: string | undefined;
        callback_url?: string | undefined;
        win_res?: string | undefined;
        mac_res?: string | undefined;
        quality?: "Compressed" | "Original" | undefined;
        wait_time?: number | undefined;
        orientation?: "portrait" | "landscape" | undefined;
        screenshots?: ({
            id: string;
            state: "failed" | "done" | "pending";
            url: string;
            os: string;
            os_version: string;
        } & ({
            device: string;
            browser?: string | undefined;
            browser_version?: string | undefined;
        } | {
            browser: string;
            browser_version: string;
        }) & {
            image_url?: string | undefined;
            thumb_url?: string | undefined;
            created_at?: string | undefined;
        })[] | undefined;
    } & {
        id: string;
    }>>;
}
